summaryrefslogtreecommitdiff
path: root/cesar/lib/src
diff options
context:
space:
mode:
authorNicolas Schodet2010-11-23 14:14:43 +0100
committerNicolas Schodet2010-12-08 17:41:56 +0100
commit38038bc8a554caf8db2f78d786b5fc0033153654 (patch)
tree6012c3de4ff3177b1fb9c24c5520db1d5bafbdd9 /cesar/lib/src
parent74b96133757bacc1901b40a0bb398246635a7bfe (diff)
cesar/lib, cesar/hal/hle: signal end of dump using a zero size, refs #2062
Diffstat (limited to 'cesar/lib/src')
-rw-r--r--cesar/lib/src/dbg.c6
1 files changed, 4 insertions, 2 deletions
diff --git a/cesar/lib/src/dbg.c b/cesar/lib/src/dbg.c
index 229151d406..32d560df70 100644
--- a/cesar/lib/src/dbg.c
+++ b/cesar/lib/src/dbg.c
@@ -92,13 +92,13 @@ dbg_fatal (const char *fmt, ...)
* Default dump callback, dump on stderr.
* \param user ignored user parameter
* \param text text to dump
* \param text_size size of text
* \return size of dumped text
*/
static int
dbg_default_dump_cb (void *user, const char *text, uint text_size)
{
- dbg_assert (text && text_size);
+ dbg_assert ((text && text_size) || text_size == 0);
arch_io_write (text, text_size);
return text_size;
}
@@ -161,6 +161,8 @@ dbg_vfatal_internal (const char *fmt, va_list ap)
}
in_fatal = false;
}
+ /* Signal end of dump. */
+ cb (dbg_dump_cb_user, NULL, 0);
/* Signal on blinking GPIO. */
#if CONFIG_GPIO_FATAL_BLINK
while (1)
@@ -92,13 +92,13 @@ dbg_fatal (const char *fmt, ...)
* \param user ignored user parameter
* \param text text to dump
- * \param text_size size of text
+ * \param text_size size of text or 0 for end of dump
* \return size of dumped text
*/